==> atmosphere-core-0.2-sources.jar: org/atmosphere/core/Broadcastable.java <==
/*
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2007-2008 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 *
 * Contributor(s):
 *
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.atmosphere.core;

import org.atmosphere.cpr.Broadcaster;
import org.atmosphere.cpr.MessageTransformer;

/**
 * Simple placeholder that can be used to broadcast message using a specific
 * {@link Broadcaster}.
 * 
 * @author Jeanfrancois Arcand
 */
public class Broadcastable {
    public String message;
    public Broadcaster b;

    public Broadcastable(String message,Broadcaster b){
        this.b = b;
        this.message = message;
    }

    /**
     * Broadcast the message.
     * @return the transformed message ({@link MessageTransformer})
     */
    public String broadcast(){
        return (String)b.broadcast(message);
    }
}

==> atmosphere-core-0.3-sources.jar: org/atmosphere/core/Broadcastable.java <==
/*
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2007-2008 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 *
 * Contributor(s):
 *
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.atmosphere.core;

import java.util.concurrent.ExecutionException;
import java.util.logging.Level;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.atmosphere.cpr.Broadcaster;
import org.atmosphere.cpr.BroadcastFilter;
import org.atmosphere.util.LoggerUtils;

/**
 * Simple placeholder that can be used to broadcast message using a specific
 * {@link Broadcaster}.
 * 
 * @author Jeanfrancois Arcand
 */
public class Broadcastable<E>{
    public E message;
    public Broadcaster<HttpServletRequest,HttpServletResponse,E> b;

    public Broadcastable(E message,Broadcaster<HttpServletRequest,HttpServletResponse,E>  b){
        this.b = b;
        this.message = message;
    }

    /**
     * Broadcast the message.
     * @return the transformed message ({@link BroadcastFilter})
     */
    public E broadcast(){
        try {
            return b.broadcast(message).get();
        } catch (InterruptedException ex) {
            LoggerUtils.getLogger().log(Level.SEVERE, null, ex);
        } catch (ExecutionException ex) {
            LoggerUtils.getLogger().log(Level.SEVERE, null, ex);
        }
        return null;
    }
}
